@@ -16,8 +16,9 @@ from omfit_classes.omfit_namelist import OMFITnamelist
 from omfit_classes.omfit_ascii import OMFITascii
 import numpy as np
 import fortranformat
+from omfit_classes.utils_fusion import tokamak
 
-__all__ = ['OMFITmhdin', 'OMFITdprobe', 'OMFITnstxMHD']
+__all__ = ['OMFITmhdin', 'OMFITdprobe', 'OMFITnstxMHD', 'get_mhdindat']
 
 
 class OMFITmhdin(OMFITnamelist):
@@ -1007,6 +1008,33 @@ class OMFITnstxMHD(SortedDict, OMFITascii):
         return self
 
 
+def get_mhdindat(device, pulse=None):
+    """
+    :param device: name of the device to get the mhdin.dat file of
+
+    :param pulse: for certain devices the mhdin.dat depends on the shot number
+
+    :return: OMFITmhdin object
+    """
+    device = tokamak(device, 'OMAS', True, translation_dict={'nstx': 'nstxu'})
+
+    if device == 'nstxu':
+        from omas.machine_mappings.nstxu import nstx_filenames
+
+        if pulse is None:
+            pulse = 1e10
+        mhdin_dat_filename = nstx_filenames('mhdin', pulse)
+
+    else:
+        from omas import omas_dir
+
+        mhdin_dat_filename = os.sep.join([omas_dir, 'machine_mappings', 'support_files', device, 'mhdin.dat'])
+
+    from omas.machine_mappings._common import get_support_file
+
+    return get_support_file(OMFITmhdin, mhdin_dat_filename)
+
+
 ############################################
 if '__main__' == __name__:
     from matplotlib import pyplot
